==> cxf-rt-transports-http-3.0.4-sources.jar: org/apache/cxf/transport/http/auth/DefaultBasicAuthSupplier.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.transport.http.auth;

import java.net.URI;

import org.apache.cxf.common.util.Base64Utility;
import org.apache.cxf.configuration.security.AuthorizationPolicy;
import org.apache.cxf.message.Message;

public final class DefaultBasicAuthSupplier implements HttpAuthSupplier {
    public DefaultBasicAuthSupplier() {
        super();
    }

    public boolean requiresRequestCaching() {
        return false;
    }
    
    public static String getBasicAuthHeader(String userName, String passwd) {
        String userAndPass = userName + ":" + passwd;
        return "Basic " + Base64Utility.encode(userAndPass.getBytes());
    }

    public String getAuthorization(AuthorizationPolicy  authPolicy,
                                   URI currentURI,
                                   Message message,
                                   String fullHeader) {
        if (authPolicy.getUserName() != null && authPolicy.getPassword() != null) {
            return getBasicAuthHeader(authPolicy.getUserName(), 
                                      authPolicy.getPassword());
        } else {
            return null;
        }
    }

}

==> cxf-rt-transports-http-3.0.16-sources.jar: org/apache/cxf/transport/http/auth/DefaultBasicAuthSupplier.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.transport.http.auth;

import java.io.UnsupportedEncodingException;
import java.net.URI;

import org.apache.cxf.common.util.Base64Utility;
import org.apache.cxf.common.util.PropertyUtils;
import org.apache.cxf.configuration.security.AuthorizationPolicy;
import org.apache.cxf.message.Message;

public final class DefaultBasicAuthSupplier implements HttpAuthSupplier {
    private static final String ENCODE_BASIC_AUTH_WITH_ISO8859 = "encode.basicauth.with.iso8859";
    public DefaultBasicAuthSupplier() {
        super();
    }

    public boolean requiresRequestCaching() {
        return false;
    }
    
    public static String getBasicAuthHeader(String userName, String passwd) {
        return getBasicAuthHeader(userName, passwd, false);
    }
    
    public static String getBasicAuthHeader(String userName, String passwd, boolean useIso8859) {
        String userAndPass = userName + ":" + passwd;
        byte[] authBytes = null;
        if (useIso8859) {
            try {
                authBytes = userAndPass.getBytes("ISO-8859-1");
            } catch (UnsupportedEncodingException ex) {
                authBytes = userAndPass.getBytes();
            }
        } else {
            authBytes = userAndPass.getBytes();
        }
        return "Basic " + Base64Utility.encode(authBytes);
    }

    public String getAuthorization(AuthorizationPolicy  authPolicy,
                                   URI currentURI,
                                   Message message,
                                   String fullHeader) {
        if (authPolicy.getUserName() != null && authPolicy.getPassword() != null) {
            boolean encodeBasicAuthWithIso8859 = PropertyUtils.isTrue(
                message.getContextualProperty(ENCODE_BASIC_AUTH_WITH_ISO8859));
            return getBasicAuthHeader(authPolicy.getUserName(), 
                                      authPolicy.getPassword(),
                                      encodeBasicAuthWithIso8859);
        } else {
            return null;
        }
    }

}
